#
# spec file for package saxon10
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global saxon_version 10
%global saxon_release 9
%global saxon_compat_version 10
# net.sf.saxon.om.XMLChar is from ASL-licensed Xerces
Name:           saxon%{saxon_version}
Version:        %{saxon_version}.%{saxon_release}
Release:        4.3
Summary:        The SAXON XSLT Processor from Michael Kay
License:        Apache-2.0 AND MPL-2.0
Group:          Productivity/Publishing/XML
URL:            https://www.saxonica.com/
Source0:        https://github.com/Saxonica/Saxon-HE/raw/main/%{saxon_version}/source/saxon%{saxon_version}-%{saxon_release}source.zip
# %{name}-generate-tarball.sh
Source1:        saxon-resources-%{saxon_version}-cleaned.zip
Source2:        https://repo1.maven.org/maven2/net/sf/saxon/Saxon-HE/%{saxon_version}.%{saxon_release}/Saxon-HE-%{saxon_version}.%{saxon_release}.pom
Source3:        %{name}.build.xml
Source10:       %{name}.saxon.script
Source11:       %{name}.saxonq.script
Source12:       %{name}.gizmo.script
Source20:       %{name}.saxon.pod
Source21:       %{name}.saxonq.pod
Source22:       %{name}.gizmo.pod
# run saxon10-generate-tarball.sh script to remove potential nonfree content from saxon-resources-10.zip.
Source100:      %{name}-generate-tarball.sh
BuildRequires:  ant
BuildRequires:  dom4j
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  icu4j
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  jdom
BuildRequires:  jdom2
BuildRequires:  jetbrains-annotations
BuildRequires:  jline >= 2
BuildRequires:  sed
BuildRequires:  unzip
BuildRequires:  xml-commons-apis
BuildRequires:  xml-commons-resolver
BuildRequires:  xom
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{name}-scripts
Provides:       jaxp_transform_impl = %{version}
BuildArch:      noarch

%description
The Saxon package is a collection of tools for processing XML documents. The
main components are:

• An XSLT processor, which can be used from the command line, or invoked from
an application, using a supplied API. Saxon implements the XSLT 3.0
Recommendation. The product can also be used to run XSLT 2.0 stylesheets, or
XSLT 1.0 stylesheets in backwards compatibility mode.

• An XPath processor accessible to applications via a supplied API. This
supports XPath 2.0 and XPath 3.1. It can also be used in
backwards-compatibility mode to evaluate XPath 1.0 expressions.

• An XQuery processor that can be used from the command line, or invoked from
an application by use of a supplied API. This supports XQuery 3.1, which also
allows XQuery 1.0 or 3.0 queries to be executed. With Saxon-EE, you can also
use the XQuery extensions defined in the XQuery Update 1.0 Recommendation, but
later working drafts of XQuery Update are not supported (W3C has abandoned work
on these versions).

• An XML Schema Processor. This supports both XSD 1.0 and XSD 1.1. This can be
used on its own to validate a schema for correctness, or to validate a source
document against the definitions in a schema. It is also used to support the
schema-aware functionality of the XSLT and XQuery processors. Like the other
tools, it can be run from the command line, or invoked from an application.

• On the Java platform, when using XSLT, XPath, XQuery, or XML schema
validation, Saxon offers a choice of APIs. If you need portability across
different vendors' tools, you can use the JAXP API for XSLT, XPath, and XML
Schema processing, and the XQJ interface for XQuery. On the other hand, if you
want a more integrated and complete API offering access to all Saxon's
facilities, the s9api interface is recommended. You can also dive down deeper
into the Saxon internals if you need to: there has been no particular attempt
to make interfaces private, and all public interfaces are documented in the
JavaDoc. Clearly, the deeper you go, the greater the risk of interfaces
changing in future releases.

• On the .NET platform, Saxon offers an API that enables close integration with
other services available from .NET, notably the XML-related classes in the
System.Xml namespace. It isn't possible to use Saxon as a transparent plug-in
replacement for the System.Xml.Xsl processor, because the API for the Microsoft
engine using concrete classes rather than abstract interfaces. However, it is
possible to use it as a functional replacement with minor changes to your
application code.

%package		manual
Summary:        Manual for %{name}
Group:          Productivity/Publishing/XML

%description	manual
Manual for %{name}.

%package		javadoc
Summary:        Javadoc for %{name}
Group:          Productivity/Publishing/XML

%description	javadoc
Javadoc for %{name}.

%package		demo
Summary:        Demos for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}

%description	demo
Demonstrations and samples for %{name}.

%package		scripts
Summary:        Utility scripts for %{name}
Group:          Productivity/Publishing/XML
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-tools
Requires:       jaxp_parser_impl
Requires:       jline
Requires:       xml-commons-apis
Recommends:     icu4j
Recommends:     jdom
Recommends:     jdom2
Recommends:     xml-commons-resolver
Recommends:     xom

%description	scripts
Utility scripts for %{name}.

%prep
%setup -q -c
unzip -q %{SOURCE1}
cp -p %{SOURCE3} ./build.xml

# purge EE imports
find -name \*.java |xargs sed -i -e 's/\(^import com\.saxonica\..*\)/\/\/\1/'

# deadNET
rm -rf net/sf/saxon/dotnet

# This requires a EE edition feature (com.saxonica.xsltextn)
rm -rf net/sf/saxon/option/sql/SQLElementFactory.java

# cleanup unnecessary stuff we'll build ourselves
rm -rf docs/api
find . \( -name "*.jar" -name "*.pyc" \) -delete

mkdir -p build/classes
cat >build/classes/edition.properties <<__PROPERTIES__
config=net.sf.saxon.Configuration
platform=net.sf.saxon.java.JavaPlatform
__PROPERTIES__

%build
export CLASSPATH=$(build-classpath xml-commons-apis jdom jdom2 xom dom4j icu4j xml-commons-resolver jline jetbrains-annotations)
ant \
	-Dj2se.javadoc=%{_javadocdir}/java \
	-Djdom.javadoc=%{_javadocdir}/jdom \
	-Ddom4j.javadoc=%{_javadocdir}/dom4j

pod2man --release='%{name} %{version}' --section=1 --center='User Commands' --quotes=none %{SOURCE20} %{name}.1
pod2man --release='%{name} %{version}' --section=1 --center='User Commands' --quotes=none %{SOURCE21} %{name}q.1
pod2man --release='%{name} %{version}' --section=1 --center='User Commands' --quotes=none %{SOURCE22} gizmo%{saxon_version}.1

%install

# JARs, POM, API documentation
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 build/lib/saxon.jar %{buildroot}%{_javadir}/%{name}.jar

install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE2} %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -r build/api %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

# Demo
install -dm0755 %{buildroot}%{_defaultdocdir}/%{name}
cp -rf use-cases samples drivers %{buildroot}%{_defaultdocdir}/%{name}

# Scripts
install -dm0755 %{buildroot}%{_bindir}
install -m0755 %{SOURCE10} %{buildroot}%{_bindir}/%{name}
install -m0755 %{SOURCE11} %{buildroot}%{_bindir}/%{name}q
install -m0755 %{SOURCE12} %{buildroot}%{_bindir}/gizmo%{saxon_version}

# Manual pages
install -dm0755 %{buildroot}%{_mandir}/man1
install -Dm0644 {%{name}{,q},gizmo%{saxon_version}}.1 %{buildroot}%{_mandir}/man1/

# jaxp_transform_impl ghost symlink
install -dm0755 %{buildroot}%{_sysconfdir}/alternatives/
ln -sf %{_sysconfdir}/alternatives/jaxp_transform_impl.jar %{buildroot}%{_javadir}/jaxp_transform_impl.jar

# Manual
install -dm0755 %{buildroot}%{_defaultdocdir}/%{name}/{doc,source-userdoc}
cp -rf doc/{index.html,img} %{buildroot}%{_defaultdocdir}/%{name}/doc
unzip -qq -d %{buildroot}%{_defaultdocdir}/%{name}/source-userdoc source-userdoc.zip
ln -s %{_javadocdir}/%{name} %{buildroot}%{_defaultdocdir}/%{name}/javadoc
find %{buildroot}%{_defaultdocdir}/%{name} \
	-name \*.class -delete -or -name \*.exe -delete
find %{buildroot}%{_defaultdocdir}/%{name} \
	\( -name \*.cs \
	-or -name \*.xml \
	-or -name \*.xsl \
	-or -name \*.xq \
	-or -name \*.xqlib \
	-or -name \*.dtd \
	-or -name \*.xsd \
	-or -name \*.resx \
	-or -name \*.out \
	-or -name \*.cmd \
	\) -print0 \
	|xargs -0 dos2unix
%fdupes %{buildroot}%{_defaultdocdir}/%{name}

%post
update-alternatives --install %{_javadir}/jaxp_transform_impl.jar \
	jaxp_transform_impl %{_javadir}/%{name}.jar 25

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove jaxp_transform_impl %{_javadir}/%{name}.jar
fi

%files -f .mfiles
%{_javadir}/jaxp_transform_impl.jar
%ghost %{_sysconfdir}/alternatives/jaxp_transform_impl.jar
%license notices/{ASM,ICU-J,JAMESCLARK,JLINE2,LICENSE,THAI,UNICODE}.txt

%files manual
%{_defaultdocdir}/%{name}
%exclude %{_defaultdocdir}/%{name}/drivers
%exclude %{_defaultdocdir}/%{name}/samples
%exclude %{_defaultdocdir}/%{name}/use-cases

%files javadoc
%{_javadocdir}/%{name}

%files demo
%{_defaultdocdir}/%{name}/drivers
%{_defaultdocdir}/%{name}/samples
%{_defaultdocdir}/%{name}/use-cases

%files scripts
%defattr(0755,root,root,0755)
%{_bindir}/*
%attr(0644,root,root) %{_mandir}/man1/*.1%{?ext_man}

%changelog
* Wed Sep 27 2023 Gus Kenion <gkenion@suse.com>
- Remove nonfree code from javadoc.
* Sun Mar  5 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v10.9
  * For a full list of bugs cleared in Saxon 10.9, please go to
    https://saxonica.plan.io/projects/saxon/issues and filter the
    list of bugs for those labelled as "Fixed in Maintenance
    Release 10.9".
* Fri May  6 2022 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v10.8
  * For a full list of bugs cleared in Saxon 10.8, please go to
    https://saxonica.plan.io/projects/saxon/issues and filter the
    list of bugs for those labelled as "Fixed in Maintenance
    Release 10.8".
  * For a full list of bugs cleared in Saxon 10.7, please go to
    https://saxonica.plan.io/projects/saxon/issues and filter the
    list of bugs for those labelled as "Fixed in Maintenance
    Release 10.7".
- The gizmo script renamed to gizmo10 to avoid conflict with future
  saxon11.
- Add some markup to POD documentation; adjust references to online
  documentation.
- Remove the _service file.
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Mon Jan 17 2022 Fridrich Strba <fstrba@suse.com>
- Add the 10.6 version to compatibility versions for maven
  metadata
* Sat Sep 18 2021 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v10.6
  * Bug #4759: Saxon.NET: InvalidCastException in
    sun.net.ftp.impl.FtpClient (Missing IKVM DLL from build)
  * Bug #4837: Two documents can have the same URI
  * Feature #4860: Format of numbers generated by fn:xml-to-json
  * Bug #4875: Testing option -unfolded is not working
  * Bug #4968: Saxon-EE 10.5: Bug #3800 reproduced
  * Bug #4969: Invalid schema-aware SEF (Invalid alpha code)
  * Bug #4970: line/column number in trace listener
  * Bug #4971: Deleting an entry from NamespaceMap can cause
    IndexOutOfBoundsException
  * Bug #4973: Schema for XML namespace is being fetched using HTTP
    rather than using the local copy
  * Bug #4974: XQuery Update: namespace propagation is not working
  * Bug #4975: Null pointer exception when outputting a warning
    with missing location information
  * Bug #4981: saxon:in-summer-time extension function: can it
    return empty sequence?
  * Bug #4982: Loading xml schemas which are stored inside
    a zip archive is very slow compared to Xerces
  * Bug #4985: NullPointerException in Saxon-EE
  * Bug #4987: NPE when references to static XSLT parameters
    appear in non-static expressions
  * Bug #4995: Schema validator throws exception if there are
    IDREFs with no corresponding ID
  * Bug #4996: Namespace information missing from default
    XML Schema attribute added by validating XMLReader
  * Bug #5000: LoopLifter NPE after updating to Saxon 10.5 EE
  * Bug #5004: Incorrect update of namespace maps
  * Bug #5005: XdmNode.Children(uri, localname) not returning
    results (.NET)
  * Bug #5006: Streamed shallow copy changes type annotation
    from xs:untyped to xs:anyType
  * Bug #5007: Streaming of fn:subsequence#2
  * Feature #5012: Support UTF-16LE and UTF-16BE in
    bin:encode-string() and bin-decode-string()
  * Bug #5013: saxon:capture doesn't copy accumulator
  * Bug #5014: NullPointerException with use of capturing
    accumulator in match pattern
  * Bug #5015: `fn:uri-collection()` calls the CollectionFinder
    associated with the Configuration, not the Controller
  * Bug #5018: suppress-indentation should prevent word-wrapping
    of HTML and XHTML output
  * Bug #5023: In a streamed transformation using
    distinct-values(), the xs:double value NaN
    and the xs:float value NaN are considered distinct
  * Bug #5026: ClassCastException:
    net.sf.saxon.functions.ScalarSystemFunction$1 cannot be cast
    to net.sf.saxon.expr.Literal
  * Bug #5032: Saxon-HE 10.5N NuGet Package cannot simply be used
    to replace binaries
  * Bug #5035: SXST0067 Component cannot be streamed, although
    it is guaranteed streamable according to W3C rules.
    No watch implemented for locVarRef
  * Bug #5044: Java reflexive calls, NullPointerException when
    argument is null
  * Bug #5045: HTML5 serialisation: DOCTYPE should not be output
    unless the outermost element is HTML
  * Bug #5047: Whitespace stripping in DocumentBuilder ignores
    xml:space
  * Bug #5048: Wrong result from map:merge() where one operand
    is a saxon:range-key
  * Bug #5049: Collation keys for alphanumeric collations are not
    correctly ordered
  * Bug #5054: Internal error optimising an inline function
    that calls its containing named function
  * Bug #5060: Overzealous type checking for lookup operator
  * Bug #5061: Empty values in text constructors: data(text { ... })
  * Bug #5063: Repository information at
    https://www.saxonica.com/documentation10/index.html#!about/support/patches
    is out of date
  * Bug #5064: Lookup expression `X?(<a>1</a>)` fails to parse
  * Bug #5065: xml-to-json() fails to report invalid input
  * Bug #5068: saxon:assign doesn't check that the value is of
    the required type
  * Bug #5069: Signatures of fold-left/fold-right are incorrectly
    documented
  * Bug #5071: saxon:decimal-divide()
  * Bug #5075: Namespace Inherit Issue on XMLStreamWriter on
    Saxon 10
  * Bug #5076: ClassCastException with match="$var" when the value
    of $var is atomic
  * Bug #5080: In .NET, the IEnumerable returned by Children
    and by Steps can only be used once
  * Bug #5084: Schema processing: invalid attribute reported twice
  * Bug #5085: Function annotations not reported for anonymous
    functions
  * Bug #5086: saxon:evaluate() fails with NullPointerException
    after importing from SEF
  * Bug #5087: Poor diagnostics when stylesheet is not exportable
  * Bug #5088: xsl:for-each with Saxon extension attribute
    separator - failure on export/import
  * Bug #5089: Test case deep-update-011 fails with export:on
  * Bug #5090: xsl:source-document extension attributes lost
    on package export/import
  * Bug #5091: Tests that optimize a filter expression to use
    a key fail after export/import
  * Bug #5092: "java.lang.AssertionError: **** Component reference
    mode xsl:unnamed is already bound" when using mode #all
    and COMPILE_WITH_TRACING == true
  * Bug #5093: AssertionError during trace code injection
  * Bug #5094: Caching of last() at context level is not working
- Use spec-cleaner
- Set mode="localonly" in the _service file
* Fri Apr 16 2021 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v10.5
* Wed Nov 18 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Specify Maven compat version as 10 to avoid conflict with saxon9.
* Tue Nov 17 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Installation locations for Maven artifacts were mistakenly
  accounted twice.
* Tue Nov 17 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Code samples were packaged twice: in "demo" and "manual"
  subpackages. Now they are located in the demo subpackage.
- Files from "demo" subpackage are moved to default documentation
  directory.
* Sat Oct 31 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Specify net.sf.saxon.TransformerFactoryImpl as a service
  provider for javax.xml.transform.TransformerFactory
- Package manual source files
* Thu Oct 29 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Update to v10.3
- Add the gizmo script.
- Update obsolete and incomplete manual pages.
  Sources for manual pages now provided as POD files.
- Remove unnecessary dependencies.
- Cleanup the spec file.
- Remove unneeded patch.
- Update package description.
* Thu Sep 24 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Package forgotten resources under net/sf/saxon/data/ into JAR file
* Wed Aug 26 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Update to v10.2
* Thu May 14 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Update to v10.1
* Wed Apr  1 2020 Anton Shvetz <tz@sectorb.msk.ru>
- Initial commit with v10.0
